PhoneNumberChecker class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Methods
containsPhoneNumber ({required String text , int minLength = 7 , int maxLength = 15 })
→ Future <bool >
Public method to check if a given text contains a phone number in digits, words, or mixed format.
This method runs in a separate isolate using Isolate.run .