PartialMask class
Partially masks the matched word, keeping the first character visible. For words with 4+ characters, also keeps the last character visible.
obscureSymbol must be exactly one character (e.g. '*', '#', 'X'),
defaults to kDefaultObscureSymbol.
- Inheritance
-
- Object
- MaskStrategy
- ObscureSymbolStrategy
- PartialMask
Constructors
- PartialMask({String obscureSymbol = kDefaultObscureSymbol})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- obscureSymbol → String
-
obscureSymbol must be exactly one character (e.g.
'*','#','X'), defaults to kDefaultObscureSymbol.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited